# Vekla

A language for spatio-temporal reasoning.

**This is a placeholder package.** The project is under active development.

- Website: [vekla.dev](https://vekla.dev)
- GitHub: [github.com/vekla-lang](https://github.com/vekla-lang)
